@@ -1,6 +1,6 @@
 import time
 
-from constant import WaiterConstant
+from zoo_framework.constant import WaiterConstant
 from zoo_framework.handler.event_reactor import EventReactor
 
 from zoo_framework.constant import WorkerConstant
